@@ -17,7 +17,7 @@ class RandomForestEdgeLabelPrediction(SklearnEdgeLabelPredictionAdapter):
         min_samples_split: int = 2,
         min_samples_leaf: int = 1,
         min_weight_fraction_leaf: float = 0.,
-        max_features="auto",
+        max_features="sqrt",
         max_leaf_nodes=None,
         min_impurity_decrease=0.,
         min_impurity_split=None,
@@ -30,6 +30,7 @@ class RandomForestEdgeLabelPrediction(SklearnEdgeLabelPredictionAdapter):
         ccp_alpha=0.0,
         max_samples=None,
         edge_embedding_method: str = "Concatenate",
+        use_edge_metrics: bool = False,
         random_state: int = 42
     ):
         """Create the Random Forest for Edge Label Prediction."""
@@ -75,8 +76,9 @@ class RandomForestEdgeLabelPrediction(SklearnEdgeLabelPredictionAdapter):
                 ccp_alpha=ccp_alpha,
                 max_samples=max_samples
             ),
-            edge_embedding_method,
-            random_state
+            edge_embedding_method=edge_embedding_method,
+            use_edge_metrics=use_edge_metrics,
+            random_state=random_state
         )
     
     @classmethod
