@@ -33,7 +33,7 @@ class GradientBoostingEdgePrediction(SklearnEdgePredictionAdapter):
         training_unbalance_rate: float = 1.0,
         training_sample_only_edges_with_heterogeneous_node_types: bool = False,
         use_edge_metrics: bool = False,
-        use_zipfian_sampling: bool = True,
+        use_scale_free_distribution: bool = True,
         prediction_batch_size: int = 2**12,
         random_state: int = 42
     ):
@@ -75,7 +75,7 @@ class GradientBoostingEdgePrediction(SklearnEdgePredictionAdapter):
             edge_embedding_method=edge_embedding_method,
             training_unbalance_rate=training_unbalance_rate,
             use_edge_metrics=use_edge_metrics,
-            use_zipfian_sampling=use_zipfian_sampling,
+            use_scale_free_distribution=use_scale_free_distribution,
             training_sample_only_edges_with_heterogeneous_node_types=training_sample_only_edges_with_heterogeneous_node_types,
             prediction_batch_size=prediction_batch_size,
             random_state=random_state
