@@ -96,7 +96,7 @@ def graph_to_sparse_tensor(
     return tf.SparseTensor(
         graph.get_directed_edge_node_ids(),
         (
-            graph.get_edge_weights()
+            graph.get_directed_edge_weights()
             if use_weights
             else tf.ones(graph.get_number_of_directed_edges())
         ),
@@ -424,13 +424,13 @@ class AbstractGCN(AbstractClassifierModel):
                     raise ValueError(
                         f"You have provided {len(feature_names)} "
                         f"{feature_category} names but you have provided {len(features)} "
-                        "{feature_category}s to the model."
+                        f"{feature_category}s to the model."
                     )
                 input_features.extend([
                     Input(
                         shape=node_feature.shape[1:],
                         batch_size=nodes_number,
-                        name=node_feature_name
+                        name=node_feature_name,
                     )
                     for node_feature, node_feature_name in zip(
                         features,
