@@ -4,6 +4,7 @@ from ensmallen import Graph, express_measures
 import numpy as np
 import pandas as pd
 import time
+from userinput.utils import closest
 from tqdm.auto import trange, tqdm
 from embiggen.utils.abstract_models.list_formatting import format_list
 from cache_decorator import Cache
@@ -670,7 +671,7 @@ class AbstractClassifierModel(AbstractModel):
                     )
                 )
 
-            if graph.get_directed_edges_number() != ef.shape[0]:
+            if graph.get_number_of_directed_edges() != ef.shape[0]:
                 raise ValueError(
                     (
                         "The provided edge features have {rows_number} rows "
@@ -806,6 +807,9 @@ class AbstractClassifierModel(AbstractModel):
                 f"the {self.model_name()} requires edge types."
             )
 
+        if support is None:
+            support = graph
+
         try:
             self._fit(
                 graph=graph,
@@ -872,22 +876,29 @@ class AbstractClassifierModel(AbstractModel):
                 "Do call the `.fit` method before the `.predict` "
                 "method."
             ))
+
+        if support is None:
+            support = graph
+        
         try:
-            return self._predict(
+            predictions = self._predict(
                 graph=graph,
                 support=support,
                 node_features=self.normalize_node_features(
                     graph=graph,
+                    random_state=self._random_state,
                     node_features=node_features,
                     allow_automatic_feature=False,
                 ),
                 node_type_features=self.normalize_node_type_features(
                     graph=graph,
+                    random_state=self._random_state,
                     node_type_features=node_type_features,
                     allow_automatic_feature=True,
                 ),
                 edge_features=self.normalize_edge_features(
                     graph=graph,
+                    random_state=self._random_state,
                     edge_features=edge_features,
                     allow_automatic_feature=False,
                 ),
@@ -898,6 +909,8 @@ class AbstractClassifierModel(AbstractModel):
                 f"implemented using the {self.library_name()} for the {self.task_name()} task. "
                 f"Specifically, the class of the model is {self.__class__.__name__}."
             ) from e
+            
+        return predictions
 
     def predict_proba(
         self,
@@ -934,8 +947,11 @@ class AbstractClassifierModel(AbstractModel):
                 "method."
             ))
 
+        if support is None:
+            support = graph
+
         try:
-            return self._predict_proba(
+            predictions = self._predict_proba(
                 graph=graph,
                 support=support,
                 node_features=self.normalize_node_features(
@@ -964,6 +980,23 @@ class AbstractClassifierModel(AbstractModel):
                 f"Specifically, the class of the model is {self.__class__.__name__}."
             ) from e
 
+        if (
+            not self.is_binary_prediction_task() and
+            not self.is_multilabel_prediction_task() and
+            (
+                len(predictions.shape) == 1 or
+                predictions.shape[1] == 2
+            )
+        ):
+            raise ValueError(
+                "This task is not a binary prediction, "
+                f"yet the {self.model_name()} model predict proba method has "
+                "returned a vector of prediction probabilities with "
+                f"shape {predictions.shape}."
+            )
+            
+        return predictions
+
     def evaluate_predictions(
         self,
         ground_truth: np.ndarray,
@@ -1002,7 +1035,7 @@ class AbstractClassifierModel(AbstractModel):
                 metric.__name__: metric(
                     ground_truth,
                     predictions,
-                    average="binary" if self.is_binary_prediction_task() else "macro",
+                    average="macro",
                     zero_division=0
                 )
                 for metric in (
@@ -1027,7 +1060,6 @@ class AbstractClassifierModel(AbstractModel):
         prediction_probabilities: np.ndarray
             The predictions to be evaluated.
         """
-        metrics = []
         if self.is_binary_prediction_task():
             return {
                 "auroc": express_measures.binary_auroc(
@@ -1044,18 +1076,16 @@ class AbstractClassifierModel(AbstractModel):
         def wrapper_roc_auc_score(*args, **kwargs):
             return roc_auc_score(*args, **kwargs, multi_class="ovr")
 
-        metrics.append(wrapper_roc_auc_score)
-
         return {
-            metric.__name__: metric(
+            "auroc": wrapper_roc_auc_score(
                 ground_truth,
-                prediction_probabilities,
+                prediction_probabilities
             )
-            for metric in metrics
         }
 
-    @staticmethod
+    @classmethod
     def split_graph_following_evaluation_schema(
+        cls,
         graph: Graph,
         evaluation_schema: str,
         holdout_number: int,
@@ -1077,9 +1107,12 @@ class AbstractClassifierModel(AbstractModel):
         holdouts_kwargs: Dict[str, Any]
             The kwargs to be forwarded to the holdout method.
         """
-        raise NotImplementedError(
-            "The `split_graph_following_evaluation_schema` method should be implemented "
-            "in the child classes of abstract classifier model."
+        raise ValueError(
+            f"The requested evaluation schema `{evaluation_schema}` "
+            f"is not available in model for task {cls.task_name()} "
+            f"Did you mean {closest(evaluation_schema, cls.get_available_evaluation_schemas())}? "
+            "The available evaluation schemas "
+            f"are: {format_list(cls.get_available_evaluation_schemas())}."
         )
 
     def _evaluate(
@@ -1211,7 +1244,7 @@ class AbstractClassifierModel(AbstractModel):
         cache_path="{cache_dir}/{self.task_name()}/{graph.get_name()}/holdout_{holdout_number}/{self.model_name()}/{self.library_name()}/{_hash}.csv.gz",
         cache_dir="experiments",
         enable_cache_arg_name="enable_cache",
-        args_to_ignore=["verbose", "smoke_test"],
+        args_to_ignore=["verbose", "smoke_test", "train_of_interest", "test_of_interest", "train",],
         capture_enable_cache_arg_name=True,
         use_approximated_hash=True
     )
